summary refs log tree commit diff
path: root/gnu/installer/newt
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/installer/newt')
-rw-r--r--gnu/installer/newt/keymap.scm8
-rw-r--r--gnu/installer/newt/parameters.scm (renamed from gnu/installer/newt/help.scm)15
2 files changed, 12 insertions, 11 deletions
diff --git a/gnu/installer/newt/keymap.scm b/gnu/installer/newt/keymap.scm
index 0147a0b9d5..8625afaa03 100644
--- a/gnu/installer/newt/keymap.scm
+++ b/gnu/installer/newt/keymap.scm
@@ -39,21 +39,21 @@
      #:title title
      #:info-text
      (case context
-       ((help) (G_ "Please choose your keyboard layout. \
+       ((param) (G_ "Please choose your keyboard layout. \
 It will only be used during the installation process."))
        (else (G_ "Please choose your keyboard layout. \
 It will be used during the install process, and for the installed system. \
-You can switch to different layout at any time from the help menu.")))
+You can switch to different layout at any time from the parameters menu.")))
      #:listbox-items layouts
      #:listbox-item->text layout->text
      #:sort-listbox-items? #f
      #:button-text
      (case context
-       ((help) (G_ "Continue"))
+       ((param) (G_ "Continue"))
        (else (G_ "Exit")))
      #:button-callback-procedure
      (case context
-       ((help) (const #t))
+       ((param) (const #t))
        (else
         (lambda _
           (raise
diff --git a/gnu/installer/newt/help.scm b/gnu/installer/newt/parameters.scm
index a488f5fa2a..4a34e94155 100644
--- a/gnu/installer/newt/help.scm
+++ b/gnu/installer/newt/parameters.scm
@@ -16,28 +16,29 @@
 ;;; You should have received a copy of the GNU General Public License
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
-(define-module (gnu installer newt help)
+(define-module (gnu installer newt parameters)
   #:use-module (gnu installer steps)
   #:use-module (gnu installer newt page)
   #:use-module (guix i18n)
   #:use-module (ice-9 match)
   #:use-module (newt)
-  #:export (run-help-page))
+  #:export (run-parameters-page))
 
-(define (run-help-page keyboard-layout-selection)
-  "Run a help page allowing to change the keyboard layout"
+(define (run-parameters-page keyboard-layout-selection)
+  "Run a parameters page allowing to change the keyboard layout"
   (let* ((items
           (list
            (cons (G_ "Change keyboard layout") keyboard-layout-selection)))
          (result
           (run-listbox-selection-page
-           #:info-text (G_ "This is the help menu, please choose an action.")
-           #:title (G_ "Installation help")
+           #:info-text (G_ "Please choose one of the following parameters or \
+press ‘Back’ to go back to the installation process.")
+           #:title (G_ "Installation parameters")
            #:listbox-items items
            #:listbox-item->text car
            #:sort-listbox-items? #f
            #:listbox-height 6
-           #:button-text (G_ "Continue"))))
+           #:button-text (G_ "Back"))))
     (match result
       ((_ . proc)
        (proc))